Diofant
=======

.. image:: https://travis-ci.org/diofant/diofant.svg?branch=master
    :target: https://travis-ci.org/diofant/diofant

.. image:: https://codecov.io/gh/diofant/diofant/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/diofant/diofant

.. image:: https://readthedocs.org/projects/diofant/badge/?version=latest
    :target: http://diofant.rtfd.io/en/latest/?badge=latest
    :alt: Documentation Status

A Python library for symbolic mathematics.

For `installation instructions`_ and usage information,
see the `online documentation`_.

See the `docs/aboutus.rst`_ file for credits and brief history.

`New BSD License`_ covers all files in this repository unless stated otherwise.

.. _online documentation: http://diofant.rtfd.io/en/latest/
.. _installation instructions: http://diofant.rtfd.io/en/latest/install.html#installation
.. _docs/aboutus.rst: http://diofant.rtfd.io/en/latest/aboutus.html
.. _New BSD License: https://github.com/diofant/diofant/blob/master/LICENSE
